#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 9919 2017-04-27 07:05:09Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-04-27 15:05:09 +0800 (週四, 27 四月 2017) $
# $Revision: 9919 $

class ErrorCode(object):
    NORMAL = 0
    SAVE_EMAIL = 1
    SEND_EMAIL = 2
    EMAIL_FORMAT = 3